@@ -32,7 +32,6 @@ const Mainloop = imports.mainloop;
 
 const Application = imports.application;
 const Documents = imports.documents;
-const FullscreenAction = imports.fullscreenAction;
 const Places = imports.places;
 const Presentation = imports.presentation;
 const Preview = imports.preview;
@@ -46,30 +45,13 @@ const EvinceView = new Lang.Class({
     _init: function(overlay, mainWindow) {
         this._model = null;
         this._jobFind = null;
-        this._controlsFlipId = 0;
-        this._controlsVisible = false;
         this._pageChanged = false;
         this._hasSelection = false;
         this._viewSelectionChanged = false;
-        this._fsToolbar = null;
 
         this.parent(overlay, mainWindow);
 
-        let fullscreenAction = new FullscreenAction.FullscreenAction({ window: mainWindow });
-        fullscreenAction.connect('notify::state', Lang.bind(this, this._onFullscreenChanged));
-        this.actionGroup.add_action(fullscreenAction);
-        Application.application.set_accels_for_action('view.fullscreen', ['F11']);
-
         this.getAction('bookmark-page').enabled = false;
-
-        let nightModeId = Application.application.connect('action-state-changed::night-mode',
-            Lang.bind(this, this._updateNightMode));
-
-        this.connect('destroy', Lang.bind(this,
-            function() {
-                Application.application.disconnect(nightModeId);
-                fullscreenAction.change_state(new GLib.Variant('b', false));
-            }));
     },
 
     _copy: function() {
@@ -118,7 +100,7 @@ const EvinceView = new Lang.Class({
     _findStateChanged: function(action) {
         let toolbar = this.toolbar;
         if (this.fullscreen)
-            toolbar = this._fsToolbar.toolbar;
+            toolbar = this.getFullscreenToolbar().toolbar;
 
         if (action.state.get_boolean()) {
             toolbar.searchbar.reveal();
@@ -273,12 +255,12 @@ const EvinceView = new Lang.Class({
     },
 
     onLoadFinished: function(manager, doc, docModel) {
-        this.parent(manager, doc, docModel);
-
         this.controlsVisible = false;
         this._lastSearch = '';
         this._model = docModel;
 
+        this.parent(manager, doc, docModel);
+
         if (Application.application.isBooks)
             docModel.set_sizing_mode(EvView.SizingMode.FIT_PAGE);
         else
@@ -286,7 +268,6 @@ const EvinceView = new Lang.Class({
 
         docModel.set_continuous(false);
         docModel.set_page_layout(EvView.PageLayout.AUTOMATIC);
-        this._updateNightMode();
 
         this._model.connect('page-changed', Lang.bind(this, this._onPageChanged));
 
@@ -312,7 +293,7 @@ const EvinceView = new Lang.Class({
 
         this._evView.set_model(this._model);
         this.navControls.setModel(this._model);
-        this.toolbar.setModel(this._model);
+        this.toolbar.updateTitle();
 
         this.set_visible_child_full('view', Gtk.StackTransitionType.NONE);
         this.grab_focus();
@@ -379,7 +360,7 @@ const EvinceView = new Lang.Class({
             this._showPresentation();
         } else {
             let chooser = new Presentation.PresentationOutputChooser(outputs);
-            chooser.connectJS('output-activated', Lang.bind(this,
+            chooser.connect('output-activated', Lang.bind(this,
                 function(chooser, output) {
                     if (output) {
                         this._showPresentation(output);
@@ -404,7 +385,7 @@ const EvinceView = new Lang.Class({
         this._hasSelection = hasSelection;
         this._viewSelectionChanged = true;
         if (!hasSelection)
-            this._cancelControlsFlip();
+            this.cancelControlsFlip();
     },
 
     _uriRewrite: function(uri) {
@@ -471,70 +452,6 @@ const EvinceView = new Lang.Class({
         this.getAction('zoom-out').enabled = this._evView.can_zoom_out;
     },
 
-    _syncControlsVisible: function() {
-        if (this._controlsVisible) {
-            if (this._fsToolbar)
-                this._fsToolbar.reveal();
-        } else {
-            if (this._fsToolbar)
-                this._fsToolbar.conceal();
-        }
-    },
-
-    _onFullscreenChanged: function(action) {
-        let fullscreen = action.state.get_boolean();
-
-        this.toolbar.visible = !fullscreen;
-        this.toolbar.sensitive = !fullscreen;
-
-        if (fullscreen) {
-            // create fullscreen toolbar (hidden by default)
-            this._fsToolbar = new EvinceViewFullscreenToolbar(this);
-            this._fsToolbar.setModel(this._model);
-            this.overlay.add_overlay(this._fsToolbar);
-
-            this._fsToolbar.connectJS('show-controls', Lang.bind(this,
-                function() {
-                    this.controlsVisible = true;
-                }));
-
-            Application.application.set_accels_for_action('view.fullscreen',
-                                                          ['F11', 'Escape']);
-        } else {
-            this._fsToolbar.destroy();
-            this._fsToolbar = null;
-
-            Application.application.set_accels_for_action('view.fullscreen', ['F11']);
-        }
-
-        this._syncControlsVisible();
-    },
-
-    _flipControlsTimeout: function() {
-        this._controlsFlipId = 0;
-        let visible = this.controlsVisible;
-        this.controlsVisible = !visible;
-
-        return false;
-    },
-
-     _cancelControlsFlip: function() {
-         if (this._controlsFlipId != 0) {
-             Mainloop.source_remove(this._controlsFlipId);
-             this._controlsFlipId = 0;
-         }
-     },
-
-     _queueControlsFlip: function() {
-         if (this._controlsFlipId)
-             return;
-
-         let settings = Gtk.Settings.get_default();
-         let doubleClick = settings.gtk_double_click_time;
-
-         this._controlsFlipId = Mainloop.timeout_add(doubleClick, Lang.bind(this, this._flipControlsTimeout));
-     },
-
     _onButtonPressEvent: function(widget, event) {
         let button = event.get_button()[1];
 
@@ -555,9 +472,9 @@ const EvinceView = new Lang.Class({
         if (button == 1
             && clickCount == 1
             && !this._viewSelectionChanged)
-            this._queueControlsFlip();
+            this.queueControlsFlip();
         else
-            this._cancelControlsFlip();
+            this.cancelControlsFlip();
 
         this._viewSelectionChanged = false;
 
@@ -575,21 +492,6 @@ const EvinceView = new Lang.Class({
         this._pageChanged = false;
     },
 
-    get controlsVisible() {
-        return this._controlsVisible;
-    },
-
-    set controlsVisible(visible) {
-        // reset any pending timeout, as we're about to change controls state
-        this._cancelControlsFlip();
-
-        if (this._controlsVisible == visible)
-            return;
-
-        this._controlsVisible = visible;
-        this._syncControlsVisible();
-    },
-
     search: function(str) {
         this._evView.find_search_changed();
 
@@ -642,21 +544,10 @@ const EvinceView = new Lang.Class({
         return metadata;
     },
 
-    _updateNightMode: function() {
-        if (this._model && !Application.application.isBooks) {
-            let nightMode = Application.settings.get_boolean('night-mode');
-            this._model.set_inverted_colors(nightMode);
-        }
-    },
-
     getModel: function() {
         return this._model;
     },
 
-    getFullscreenToolbar: function() {
-        return this._fsToolbar;
-    },
-
     goPrev: function() {
         this._evView.previous_page();
     },
@@ -677,8 +568,13 @@ const EvinceView = new Lang.Class({
         return this._model ? this._model.document.get_n_pages() : 0;
     },
 
-    get fullscreen() {
-        return this.getAction('fullscreen').state.get_boolean();
+    get canFullscreen() {
+        return true;
+    },
+
+    set nightMode(v) {
+        if (this._model && !Application.application.isBooks)
+            this._model.set_inverted_colors(v);
     }
 });
 
@@ -725,99 +621,8 @@ const EvinceViewToolbar = new Lang.Class({
     _init: function(preview) {
         this.parent(preview);
 
-        this._fsStateId = 0;
         this._handleEvent = false;
 
         this.addSearchButton('view.find');
-
-        if (Application.application.isBooks) {
-            this._addFullscreenButton();
-            this.addNightmodeButton();
-        }
-
-        this.connect('destroy', Lang.bind(this, function() {
-            if (this._fsStateId > 0)
-                this.preview.getAction('fullscreen').disconnect(this._fsStateId);
-        }));
-    },
-
-    _addFullscreenButton: function() {
-        this._fullscreenButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'view-fullscreen-symbolic' }),
-                                                  tooltip_text: _("Fullscreen"),
-                                                  action_name: 'view.fullscreen',
-                                                  visible: true });
-        this.toolbar.pack_end(this._fullscreenButton);
-
-        let action = this.preview.getAction('fullscreen');
-        this._fsStateId = action.connect('notify::state', Lang.bind(this, this._fullscreenStateChanged));
-        this._fullscreenStateChanged();
-    },
-
-    _fullscreenStateChanged: function() {
-        let action = this.preview.getAction('fullscreen');
-        let fullscreen = action.state.get_boolean();
-
-        if (fullscreen)
-            this._fullscreenButton.image.icon_name = 'view-restore-symbolic';
-        else
-            this._fullscreenButton.image.icon_name ='view-fullscreen-symbolic';
-    },
-
-    setModel: function() {
-        this.updateTitle();
     }
 });
-
-const EvinceViewFullscreenToolbar = new Lang.Class({
-    Name: 'EvinceViewFullscreenToolbar',
-    Extends: Gtk.Revealer,
-
-    _init: function(previewView) {
-        this.parent({ valign: Gtk.Align.START });
-
-        this.toolbar = new EvinceViewToolbar(previewView);
-
-        this.add(this.toolbar);
-        this.show();
-
-        // make controls show when a toolbar action is activated in fullscreen
-        let actionNames = ['gear-menu', 'find'];
-        let signalIds = [];
-
-        actionNames.forEach(Lang.bind(this, function(actionName) {
-            let signalName = 'action-state-changed::' + actionName;
-            let signalId = previewView.actionGroup.connect(signalName, Lang.bind(this,
-                function(actionGroup, actionName, value) {
-                    let state = value.get_boolean();
-                    if (state)
-                        this.emitJS('show-controls');
-                }));
-
-            signalIds.push(signalId);
-        }));
-
-        this.toolbar.connect('destroy', Lang.bind(this, function() {
-            signalIds.forEach(function(signalId) {
-                previewView.actionGroup.disconnect(signalId);
-            });
-        }));
-    },
-
-    handleEvent: function(event) {
-        this.toolbar.handleEvent(event);
-    },
-
-    setModel: function(model) {
-        this.toolbar.setModel(model);
-    },
-
-    reveal: function() {
-        this.set_reveal_child(true);
-    },
-
-    conceal: function() {
-        this.set_reveal_child(false);
-        this.toolbar.preview.getAction('find').change_state(GLib.Variant.new('b', false));
-    }
-});
-Utils.addJSSignalMethods(EvinceViewFullscreenToolbar.prototype);
